# polars-testing

`polars-testing` is a sub-crate of the [Polars](https://crates.io/crates/polars) library, offering
comprehensive functionality for unit testing in Rust.

## Usage

To use `polars-testing`, add it as a dependency to your Rust project's `Cargo.toml` file:

```toml
[dependencies]
polars-testing = "0.49.1"
```

You can then import the crate in your Rust code using:

```rust
use polars_testing::*;
```

**Important Note**: This crate is **not intended for external usage**. Please refer to the main
[Polars crate](https://crates.io/crates/polars) for intended usage.
